The MPL Reference Manual: Classes

Prev Next | Back Along | Up Home | Full TOC | Front Page / Sequences / Classes

# Classes

The MPL provides a large number of predefined general-purpose sequence classes covering most of the typical metaprogramming needs out-of-box.

- vector
- list
- deque
- set
- map
- range_c
- vector_c
- list_c
- set_c
- string

Prev Next | Back Along | Up Home | Full TOC | Copyright © 2001-2009 Aleksey Gurtovoy and David Abrahams Distributed under the Boost Software License, Version 1.0. (See accompanying file LICENSE_1_0.txt or copy at http://www.boost.org/LICENSE_1_0.txt)